package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````\)D$"#0```"<L````````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(+*T`
M`"RM```%`````!````$````LK0``+#T%""P]!0B$`@``U!(```8`````$```
M`@```$"M``!`/04(0#T%"`@!```(`0``!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%#E=&2DIP``I"<%"*0G!0C4````U`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````)````
M)0```%`````(````"``````0$`0E0`2`J`$``:*&`:A````"3R@$*3BB,D>*
MA`P(4````%(```````````````````!4````5@```%<```!8````60```%H`
M````````6P```%T```!>`````````%\```````````````````!@````8P``
M````````````9````&8```!G````:0````````!K````;0``````````````
M;P```'````!R`````````,C5LG%9Z.WLSMY'+:/@^TGJT^\.I]VC:R_%F[;;
MS>.>Y^]?>X?YG(%K"4/6##J7"T>8!<;%B060#13BGB'_Y`ZR`8MOQ+F<0&M_
MFGQ_J9R;;L7?']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9[\$IKXD?&
M`4-%U>Q]08[%PN4_+*$B"R#RV],=^J%L8+F-\0X`````````````````````
M&@,`````````````$@```*P``````````````!(```"O`P`````````````2
M````F@,`````````````$@```)P!`````````````!(```#?`P``````````
M```2````=0(`````````````$@````P``````````````"`````;````````
M```````@````H`,`````````````$@```(@!`````````````!(`````!```
M```````````2````:0$`````````````$@```'L!`````````````!(````\
M!``````````````2````40,`````````````$@```"L#`````````````!(`
M```G`@`````````````2````^```````````````$@```!<"````````````
M`!(```#$`P`````````````2````Q0$`````````````$@```'$$````````
M`````!(````O!``````````````2````^0(`````````````$@```#,#````
M`````````!(```"3`@`````````````2````Y0$`````````````$@```*$!
M`````````````!(````P`@`````````````2````[0,`````````````$@``
M`&,$`````````````!(````J`0`````````````2````^`,`````````````
M$@```"\``````````````!(````*!``````````````2````6`$`````````
M````$@```,,``````````````!(```!#!``````````````2````V`,`````
M````````$@```"@$`````````````!(```"]`P`````````````2````DP,`
M````````````$@```&4%`````````````!(````\`0`````````````2````
M&`0`````````````$@```%<"`````````````!(```!Y`P`````````````2
M````#0,`````````````$@```$D"`````````````!(```#+`P``````````
M```2````C`(`````````````$@```*8!`````````````!(```""`P``````
M```````2````T@,`````````````$@```+8#`````````````!(```#G````
M```````````2````/0``````````````$@```!\$`````````````!(```!;
M!``````````````2````T@``````````````$@```/D!`````````````!(`
M``"``@`````````````2````2P$`````````````$@```$T$````````````
M`!(```"H`P`````````````2````:`,`````````````$@```!,#````````
M`````!(````8`0`````````````2````/@(`````````````$@```$\`````
M`````````!(```#3`0`````````````2````7@``````````````$@```&H$
M`````````````!(```"*```````````````2````<`,`````````````$@``
M`&,#`````````````!(```!S```````````````2````!@$`````````````
M$@```+(!``!(E00(`````!(````&!0``0,D$"`0````1``X`XP4``%"V!`AL
M"@``$@`,``\&``!`LP0(GP$``!(`#```!0``',D$"``````2``T`A00``,`_
M!0@$````(0`8`-@$```@L`0("P```!(`#`"/!0``@,@$"%H````2``P`I`4`
M``#,!`BA6P``$0`.`)L````HEP0(`````!(```!Z!0``G#\%"``````0`!<`
M?`4``)P_!0@`````(``7`)\%``"H/P4(!````!$`%P"$!```P#\%"`0````A
M`!@`]@0``.#(!`@%````$@`,``(&```PL`0(YP$``!(`#``C!0``X+0$"$(`
M```2``P`@P0``,`_!0@$````$0`8`'X$```@Q@0((`(``!(`#`!3!0``,+4$
M"!X````2``P`;@4``$#%!`AS````$@`,`)0$``"P/P4(`````!``\?^@!```
M`%`%"``````0`/'_#04``,#`!`A\!```$@`,`$(#``!$R00(!````!$`#@"`
M!0``\)D$"``````2``P`,04``#"O!`CB````$@`,`$<%``!0L@0([````!(`
M#`!E`@``&)<$"``````2````Z00``""R!`@M````$@`,`(T$``"P/P4(````
M`!``\?^S!0``P,4$"%L````2``P`AP4``("N!`@]````$@`,`,\%``"L/P4(
M!````!$`%P">`@``Q#\%"!,````1`!@`\`4``%"U!`@``0``$@`,`(D%``"8
ME`0(`````!(`"@``;&EB<&5R;"YS;P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G
M:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`
M4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E
M7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO
M8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])
M=&%I;G1E9%]P='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?
M;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E
M<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R
M`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E
M;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB;G-L+G-O+C$`;&EB9&PN<V\N,@!L
M:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB<'1H<F5A
M9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R
M;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?<W1D:6Y?
M=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V
M<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(O<&5R;#4O
M-2XQ,BXS+VDS.#8M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`<&%R7V-U<G)E
M;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C
M7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N86QS7U!!
M4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`<&%R7VUK=&UP9&ER
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`
M1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`1TQ)
M0D-?,BXS+C0`1TQ)0D-?,BXP`````@````,``P````0``````````P````4`
M``````,`!@`'``````````,````#``0``@`"```````#````!0`#`````P``
M``@```````4``P`#``,``P`#`````P````,``@````,``P````D``P`#````
M```#``,````````````$``,``P`'```````````````#`````P`#````````
M``$``0`!``$``P`!``$``0````$``0`!``,``0`!``$``P`!``$``0`!``$`
M`0`!``$``0`!`````0`!``$``0`!`````0`!`````0`&`#@#```0````<```
M`!1I:0T```D`'`8``!`````3:6D-```(`"8&```0````<AEI"0``!@`P!@``
M$````!)I:0T```4`/`8``!````!T&6D)```$`$8&```0````$&EI#0```P!2
M!@````````$``@#I`@``$``````````2:6D-```'`#P&```0````$&EI#0``
M`@!2!@```````$@^!0@&"```P#\%"`5A``#$/P4(!7(``%@^!0@'`0``7#X%
M"`<"``!@/@4(!P,``&0^!0@'!```:#X%"`<%``!L/@4(!P8``'`^!0@'!P``
M=#X%"`=0``!X/@4(!P@``'P^!0@'"@``@#X%"`<+``"$/@4(!PP``(@^!0@'
M#0``C#X%"`<.``"0/@4(!P\``)0^!0@'$```F#X%"`<1``"</@4(!Q(``*`^
M!0@'$P``I#X%"`<4``"H/@4(!Q4``*P^!0@'%@``L#X%"`<7``"T/@4(!Q@`
M`+@^!0@'&0``O#X%"`<:``#`/@4(!QL``,0^!0@''```R#X%"`<=``#,/@4(
M!QX``-`^!0@''P``U#X%"`<@``#8/@4(!R$``-P^!0@'(@``X#X%"`<C``#D
M/@4(!R0``.@^!0@';```[#X%"`=9``#P/@4(!R4``/0^!0@')@``^#X%"`<G
M``#\/@4(!R@````_!0@'*0``!#\%"`<J```(/P4(!RL```P_!0@'+```$#\%
M"`<M```4/P4(!RX``!@_!0@'+P``'#\%"`<P```@/P4(!S$``"0_!0@',@``
M*#\%"`<S```L/P4(!S0``#`_!0@'-0``-#\%"`<V```X/P4(!S<``#P_!0@'
M.```0#\%"`<Y``!$/P4(!SH``$@_!0@'.P``3#\%"`<\``!0/P4(!ST``%0_
M!0@'/@``6#\%"`<_``!</P4(!T```&`_!0@'00``9#\%"`="``!H/P4(!T,`
M`&P_!0@'1```<#\%"`=%``!T/P4(!T8``'@_!0@'1P``?#\%"`=(``"`/P4(
M!TD``(0_!0@'2@``B#\%"`=+``",/P4(!TP``)`_!0@'30``E#\%"`=.``"8
M/P4(!T\``%6)Y5.#[`3H`````%N!PZBI``"+D_S___^%TG0%Z)X```#HP04`
M`.@L-```6%O)P_\U4#X%"/\E5#X%"`````#_)5@^!0AH`````.G@_____R5<
M/@4(:`@```#IT/____\E8#X%"&@0````Z<#_____)60^!0AH&````.FP____
M_R5H/@4(:"````#IH/____\E;#X%"&@H````Z9#_____)7`^!0AH,````.F`
M_____R5T/@4(:#@```#I</____\E>#X%"&A`````Z6#_____)7P^!0AH2```
M`.E0_____R6`/@4(:%````#I0/____\EA#X%"&A8````Z3#_____)8@^!0AH
M8````.D@_____R6,/@4(:&@```#I$/____\ED#X%"&AP````Z0#_____)90^
M!0AH>````.GP_O___R68/@4(:(````#IX/[___\EG#X%"&B(````Z=#^____
M):`^!0AHD````.G`_O___R6D/@4(:)@```#IL/[___\EJ#X%"&B@````Z:#^
M____):P^!0AHJ````.F0_O___R6P/@4(:+````#I@/[___\EM#X%"&BX````
MZ7#^____);@^!0AHP````.E@_O___R6\/@4(:,@```#I4/[___\EP#X%"&C0
M````Z4#^____)<0^!0AHV````.DP_O___R7(/@4(:.````#I(/[___\ES#X%
M"&CH````Z1#^____)=`^!0AH\````.D`_O___R74/@4(:/@```#I\/W___\E
MV#X%"&@``0``Z>#]____)=P^!0AH"`$``.G0_?___R7@/@4(:!`!``#IP/W_
M__\EY#X%"&@8`0``Z;#]____)>@^!0AH(`$``.F@_?___R7L/@4(:"@!``#I
MD/W___\E\#X%"&@P`0``Z8#]____)?0^!0AH.`$``.EP_?___R7X/@4(:$`!
M``#I8/W___\E_#X%"&A(`0``Z5#]____)0`_!0AH4`$``.E`_?___R4$/P4(
M:%@!``#I,/W___\E"#\%"&A@`0``Z2#]____)0P_!0AH:`$``.D0_?___R40
M/P4(:'`!``#I`/W___\E%#\%"&AX`0``Z?#\____)1@_!0AH@`$``.G@_/__
M_R4</P4(:(@!``#IT/S___\E(#\%"&B0`0``Z<#\____)20_!0AHF`$``.FP
M_/___R4H/P4(:*`!``#IH/S___\E+#\%"&BH`0``Z9#\____)3`_!0AHL`$`
M`.F`_/___R4T/P4(:+@!``#I</S___\E.#\%"&C``0``Z6#\____)3P_!0AH
MR`$``.E0_/___R5`/P4(:-`!``#I0/S___\E1#\%"&C8`0``Z3#\____)4@_
M!0AHX`$``.D@_/___R5,/P4(:.@!``#I$/S___\E4#\%"&CP`0``Z0#\____
M)50_!0AH^`$``.GP^____R58/P4(:``"``#IX/O___\E7#\%"&@(`@``Z=#[
M____)6`_!0AH$`(``.G`^____R5D/P4(:!@"``#IL/O___\E:#\%"&@@`@``
MZ:#[____)6P_!0AH*`(``.F0^____R5P/P4(:#`"``#I@/O___\E=#\%"&@X
M`@``Z7#[____)7@_!0AH0`(``.E@^____R5\/P4(:$@"``#I4/O___\E@#\%
M"&A0`@``Z4#[____)80_!0AH6`(``.DP^____R6(/P4(:&`"``#I(/O___\E
MC#\%"&AH`@``Z1#[____)9`_!0AH<`(``.D`^____R64/P4(:'@"``#I\/K_
M__\EF#\%"&B``@``Z>#Z__\``````````#'M7HGA@^3P4%12:.#(!`AH@,@$
M"%%6:"#&!`CH)_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/=@_!0@`=3^A
MW#\%"+LX/04(@>LT/04(P?L"@^L!.=AS'HVV`````(/``:/</P4(_Q2%-#T%
M"*'</P4(.=ARZ,8%V#\%"`&#Q`1;7<.-="8`C;PG`````%6)Y8/L&*$\/04(
MA<!T$K@`````A<!T"<<$)#P]!0C_T,G#D)"0D)"0D)"0D)"0D%575E.)PX'L
M6`$``(/#'(E$)!2-3"08,<"-M"8`````BQ2##\J)%(&#P`&#^!!U\(U4)$R-
MC"1,`0``D(UT)@"+0NPS`C-"U#-"S,'('XE"#(/"!#G*=>B+1"04BU0D%(M\
M)!2+7"04BP"+4@2+?PR+6PB)1"00BT0D%(E4)`R+5"08B7PD!(M,)`R)7"0(
MBT`0P<$>`<*)!"2+1"00P<`%C;P"F7F"6HM$)`R+5"0,]]`C1"0$(=H)T(M4
M)`0!QXM$)!`#5"0<B?WWT"'8BUPD$"'+"=B+7"0(C;0"F7F"6HGXBU0D$,'`
M!0'&`UPD((GPP<`%P<(>C9P#F7F"6HGX]]`AU2'(">B)]0'#B?#!QQ[WT`-,
M)"0A_2'0">B)W8V,`9EY@EJ)V,'`!0'!`U0D*(G(P<`%P<8>C90"F7F"6HG8
M]]`A]2'X">B)S0'"B<C!PQ[WT`-\)"PAW2'P">B)U8V\!YEY@EJ)T,'`!0''
M`W0D,(GXP<`%P<$>C;0&F7F"6HG0]]`AS2'8">B)_0'&B?C!PA[WT`-<)#0A
MU2'(">B)]8V<`YEY@EJ)\,'`!0'#`TPD.(G8P<`%P<<>C8P!F7F"6HGP]]`A
M_2'0">B)W0'!B=C!QA[WT`-4)#PA]2'X">B)S8V4`IEY@EJ)R,'`!0'"`WPD
M0(G0P<`%P<,>C;P'F7F"6HG(]]`AW2'P">B)U0''B=#!P1[WT`-T)$0AS2'8
M">B)_8VT!IEY@EJ)^,'`!0'&`UPD2(GPP<`%P<(>C9P#F7F"6HGX]]`AU2'(
M">B)]0'#B?#!QQ[WT`-,)$PA_2'0">B)W8V,`9EY@EJ)V,'`!0'!`U0D4(G(
MP<8>P<`%(?6-E`*9>8):B=CWT"'X">B)S0'"B<C!PQ[WT`-\)%0AW2'P">B)
MU8V\!YEY@EJ)T,'`!0''`W0D6(GXP<`%P<$>C;0&F7F"6HG0]]`AS2'8">B)
M_0'&B?C!PA[WT`-<)%PAU2'(">B)]8V<`YEY@EJ)\,'`!0'#`TPD8(G8P<`%
MP<<>C8P!F7F"6HGP]]`A_2'0">B)W0'!B=C!QA[WT`-4)&0A]2'X">B-E`*9
M>8):B<C!PQ[!P`4!PHG8`WPD:#'P,<C!P1Z-O`>AZ]ENB=#!P`4#="1LC00'
MB<\QWS'7C;P^H>O9;HG&P<(>P<8%`UPD<(TT-XG7,<\QQXV\.Z'KV6Z)\\'`
M'L'#!0-,)'2-'!^)QS'7,?>-O#FAZ]ENB=G!QA[!P04#5"1XC0P/B?<QQS'?
MC;PZH>O9;HG*P<,>P<(%C107B=\#1"1\,?<QS\'!'HV\.*'KV6Z)T,'`!0.T
M)(````"-!`>)SS'?,=>-O#ZAZ]ENB<;!PA[!Q@4#G"2$````C30WB=<QSS''
MC;P[H>O9;HGSP<`>P<,%`XPDB````(T<'XG',=<Q]XV\.:'KV6Z)V<'&'L'!
M!0.4)(P```"-#`^)]S'',=^-O#JAZ]ENB<K!PQ[!P@4#A"20````C107B=\Q
M]S'/C;PXH>O9;HG0P<$>P<`%`[0DE````(T$!XG/,=\QUXV\/J'KV6Z)QL'&
M!<'"'@.<))@```"--#>)US'/,<>-O#NAZ]ENB?/!P![!PP4#C"2<````C1P?
MB<<QUS'WC;PYH>O9;HG9P<8>P<$%`Y0DH````(T,#XGW,<<QWXV\.J'KV6Z)
MRL'#'L'"!0.$)*0```"-%!>)WS'W,<^-O#BAZ]ENB=#!P1[!P`4#M"2H````
MC00'B<\QWS'7C;P^H>O9;HG&P<(>P<8%`YPDK````(TT-XG7,<\QQXV\.Z'K
MV6Z)\\'`'L'#!0.,)+````"-'!^)QS'7,?>-O#FAZ]ENB=G!QA[!P04#E"2T
M````C0P/B?<QQS'?C;PZH>O9;HG*P<(%C107B[PDN````,'#'HG=(?4!QXG8
M"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PDO````,'!'HG-(=T!]XG."=XAU@GN
MC;PWW+P;CXG&P<8%C30WB[PDP````,'"'HG5(<T!WXG3"<LAPPGKC;P?W+P;
MCXGSP<,%C1P?B[PDQ````,'`'HG%`<^)P0G1(?$AU0GIC;P/W+P;CXG9P<$%
MC0P/B[PDR````,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<(%C107B[PD
MS````,'#'HG=(?4!QXG8"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PDT````,'!
M'HG-(=T!]XG."=XAU@GNC;PWW+P;CXG&P<8%C30WB[PDU````,'"'HG5(<T!
MWXG3"<LAPPGKC;P?W+P;CXGSP<,%C1P?B[PDV````,'`'HG%`<^)P0G1(=4A
M\0GIC;P/W+P;CXG9P<$%C0P/B[PDW````,'&'HGU(<4!UXGR"<(AV@GJC;P7
MW+P;CXG*P<(%C107B[PDX````,'#'HG=(?4!QXG8"?`AR`GHC;P'W+P;CXG0
MP<`%C00'B[PDY````,'!'HG-(=T!]XG."=XAU@GNC;PWW+P;CXG&P<8%C30W
MB[PDZ````,'"'HG5(<T!WXG3"<LAPPGKC;P?W+P;CXGSP<,%C1P?B[PD[```
M`,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%C0P/B[PD\````,'&'HGU
M(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<(%C107B[PD]````,'#'HG=(?4!QXG8
M"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PD^````,'!'HG-(=T!]XG."=XAU@GN
MC;PWW+P;CXG&P<8%C30WB[PD_````,'"'HG5(<T!WXG3"<LAPPGKC;P?W+P;
MCXGSP<,%C1P?B[PD``$``,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%
MC0P/B[PD!`$``,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<,>P<(%`=>)
MV@.$)`@!```Q\C'*P<$>C900UL%BRHGXP<`%C00"B<H#M"0,`0``,=HQ^@.<
M)!`!``"-M!;6P6+*B<+!P@6-%!:)_L'&'HGW,<\QQXV\.];!8LJ)T\'`'L'#
M!8T<'XG'`XPD%`$``#'W,=?!PAZ-O#G6P6+*B=G!P04!SXG1`[0D&`$``#'!
M,=G!PQZ-M`[6P6+*B?G!P04!SHG9`X0D'`$``#'1,?D#E"0@`0``C8P(UL%B
MRHGPP<`%`<&)^,'`'HG',=\Q]XV\.M;!8LJ)RL'&'L'"!0'7B?(#G"0D`0``
M,<(QRL'!'HV<$];!8LJ)^L'"!0.$)"@!``"-%!.)RS'S,?N-G!C6P6+*B=#!
MP`4!P\'''@.T)"P!``")^#'(,="-M`;6P6+*B=C!PA[!P`4#C"0P`0``C00&
MB=8Q_C'>C;0QUL%BRHG!P<,>P<$%`<Z)V0.\)#0!```QT3'!P<`>C;P/UL%B
MRHGQP<$%`Y0D.`$``(T,#XG',=\Q]XV\.M;!8LJ)RL'&'L'"!0'7B?(#G"0\
M`0``,<(QRL'!'HV<$];!8LJ)^L'"!0.$)$`!``"-%!.)RS'S,?N-G!C6P6+*
MB=#!P`4!P\'''@.T)$0!``")^#'(,="-M`;6P6+*B=C!PA[!P`6-!`:)U@.,
M)$@!```Q_C'>P<,>C;0QUL%BRHG!P<$%C0P.B=X#O"1,`0``,=8QQL'`'HV\
M-];!8LJ)SL'&!8TT-XG'`Y0D4`$``#'?,<_!P1Z-O#K6P6+*B?+!P@6-%!>+
M?"00`[PD5`$``(V\.];!8LJ)RS'#,?.-'!^)U\''!0'[BWPD%,'&'HD?`U0D
M#`-,)`0#!"2)5P2+5"0(B4\,B4<0C106B5<(@<18`0``6UY?7</K#9"0D)"0
MD)"0D)"0D)"#[#R)7"0LB<,QP(7;B70D,(E\)#2);"0XB50D''49BUPD+(MT
M)#"+?"0TBVPD.(/$/,.0C70F`(L5P#\%"(72B50D&'39#[8#/#UT!(3`=3\Q
M[8M$)!B+,#'`A?9TP(M\)!B0C70F`(EL)`B)7"0$B30DZ*#R__^%P'4&@#PN
M/70F@\<$BS>%]G7=,<#KD)")W8/%`0^V10`\/70$A,!U\2G=ZZZ-=@`K?"08
MBU0D'(U$+@'!_P*).NEA____9I"#[!R-5"0,Z#3___^#Q!S#5HG&4XGP@^P4
MC5PD#(G:Z!S___^%P'0IBT0D#,'@`@,%P#\%"(UV`(/`!(L0A=*)4/QU](G:
MB?#H\_[__X7`==>#Q!1;7L.)]HV\)P````!64X/L%,<$)`````#H-_+__XL`
MB00DZ!WO__^)!"3HI>W__XL`BW`$QP0D`````.@4\O__BP")!"3H^N[__XD$
M).@R[O__#[88QP0D`````.CS\?__@^-_BP")!"3HUN[__XD$).@>[O__BP`/
MMT`0P>`'"=AFB48"QP0D`````.C#\?__BP")!"3HJ>[__XD$).@Q[?__BP"+
M6`3'!"0`````Z*#Q__^+`(D$).B&[O__QT0D"`````#'1"0$*,L$"(D$).C^
M\/__B4,<QP0D`````.AO\?__BP")!"3H5>[__XD$).C=[/__BP"+6`3'!"0`
M````Z$SQ__^+`(D$).@R[O__B00DZ$KM__^+`(E#(,<$)`````#H*?'__XL`
MB00DZ`_N__^)!"3HE^S__XL`BU@$QP0D`````.@&\?__BP")!"3H[.W__XD$
M).@$\/__,=*+`(7`="/'!"0`````Z.#P__^+`(D$).C&[?__B00DZ-[O__^+
M`(M0;(E3),<$)`````#HNO#__XL`B00DZ*#M__^)!"3H*.S__XL`BT`$QT`H
M`````,<$)`````#HD/#__XL`B00DZ';M__^)!"3H_NO__XL`BT`$QT`8````
M`,<$)`````#H9O#__XL`B00DZ$SM__^)!"3HU.O__XL`BU@$QP0D`````.A#
M\/__BP")!"3H*>W__XD$).@!\/__BP")0RR#Q!1;7L.-M"8`````C;PG````
M`%57B<=64X'LC````(7`=`6`.`!U"X'$C````%M>7UW#B00DZ'#M__^%P(G&
M=.=FD(DT).C0[?__A<`/A,@```"-6!,/MA5)R00(#[9`$SG0=0X/MA5*R00(
M.%,!=-)FD`^V%4C)!`@YT`^$N0```(D\).C![?__B1PDB<7HM^W__XU$!0*)
M!"3H2^[__XE<)!2)?"00QT0D#$O)!`C'1"0(_____\=$)`0!````B<6)!"3H
M\>[__XU$)"")1"0(B6PD!,<$)`,```#H:>O__X/X_W00BT0D,"4`\```/0!`
M``!T;(DL).A<[?__B2PDZ%3L__^)-"3H#.W__X7`#X4\____C70F`(DT).B(
M[?__B3PDZ/#M__^!Q(P```!;7E]=PY"-="8`#[8%2<D$"#A#`0^%-____P^V
M%4K)!`@X4P(/A.C^___I(O___XUV`(GHZ*G^___KDXVT)@````!6B<93,=N#
M[!3'!"0`````Z*/N__^+`(D$).B)Z___B00DZ+'M__^)="0$QP0D`P```(E$
M)`CHS>O__X7`=`F)V(/$%%M>PY#'!"0`````Z&3N__^+`(D$).A*Z___B00D
MZ'+M__^+0!`E`/```#T`0```="W'!"0`````Z#?N__^+`(D$).@=Z___B00D
MZ$7M__^+0!`E`/```#T`H```=9V)-"0QV\=$)`0"````Z&3K__^%P`^4PX/$
M%(G86U[#ZPV0D)"0D)"0D)"0D)"055=6B<93,<"#[#R)TX`Z/0^4P`'#B1PD
MZ.OK__^-5"0LB<>)\.A6^O__A<")Q70XB00DZ-#K__\QTCG'#X>5`0``C;8`
M````#[8$$XA$%0"#P@&$P'7Q,<"#Q#Q;7E]=PXVT)@````"+%<`_!0@Q[;@(
M````BPJ%R706D(UT)@"#Q0&+!*J%P'7VC02M"````(L-\#\%"(7)#X3A````
MB40D!(D4).@]Z?__B<&%R:/`/P4(N/____]TGHT$K0````")1"0<QT2I!```
M``");"0L#[8&/#T/A`H!``"$P`^$`@$``(GPZPN-M"8`````A-)T"X/``0^V
M$(#Z/77Q*?"+;"0<C40'`@,MP#\%"(D$).B1Z___B<*%THE%`+C_____#X0P
M____BU0D+*'`/P4(BP20#[86A-*($'0>@/H]=!F#Q@'K!8#Z/70/#[86@\`!
M@\8!A-*($'7LQ@`],=*-M"8`````#[8,$XA,$`&#P@&$R77QZ=O^__^-="8`
MB50D&,<%\#\%"`$```")!"3H$NO__XM4)!B)P;C_____A<D/A+#^__^-!*T`
M````B0PDB4PD&(E$)!R)1"0(B50D!.A@Z___BTPD&(D-P#\%".GO_O__BT0D
M+,'@`HE$)!SIZ_[__XGPZ1'___]FD('L/!```(F\)#00``"-?"0<B9PD+!``
M`(G#B:PD.!```(G59:$4````B80D'!```#'`B;0D,!```,=$)`C_#P``B7PD
M!,<$)%')!`CHU^K__X7`#XZ'````@'P$&P")QG1VB70D",=$)`0O````B3PD
MZ"+K__^%P'1FQP0D`````.ARZ___BP")!"3H6.C__XET)`R)?"0(B5PD!(D$
M).BDZ?__BX0D'!```&4S!10```!U5(N<)"P0``"+M"0P$```B[PD-!```(NL
M)#@0``"!Q#P0``##D(/N`76%C78`QP0D`````.@,Z___BP")!"3H\N?__XEL
M)`B)7"0$B00DZ++G___KG.C+Z?__C78`@^P<QP0D`````.C9ZO__BP")!"3H
MO^?__\=$)`Q@R00(QT0D"!B7!`C'1"0$:LD$"(D$).B/ZO__@\0<PXUV`(/L
M+,<$)`````#HF>K__XL`B00DZ'_G__^)!"3HG____\<$)`````#H>^K__XL`
MB00DZ&'G___'1"04`````,=$)!`HRP0(QT0D#"C+!`C'1"0(P,`$",=$)`2&
MR00(B00DZ!'H__^#Q"S#D(UT)@"![#P@``")G"0P(```C9PD*Q```(FT)#0@
M```Q]F6A%````(F$)"P@```QP(F\)#@@``#HD.7__\=$)!1<R00(QT0D#)O)
M!`C'1"0(`1```,=$)`0!````B1PDB40D$.ADZ?__A<!Y,(N4)"P@``!E,Q44
M````B?!U8XN<)#`@``"+M"0T(```B[PD."```('$/"```,-FD(U\)"J)'"3'
M1"0(`!```(E\)`3HN.C__X7`B<-XLHU``8D$).@WZ/__A<")QG2AB5PD"(E\
M)`2)!"3H8>?__\8$'@#KB^@VZ/__C;0F`````(V\)P````"#[`R#Q`SI!?__
M_Y"-="8`55=64X'L3!```&6A%````(F$)#P0```QP+BGR00(BYPD8!```(NT
M)&00``#H7_;__\=$)`0O````B1PDB<7H1>7__X7`="V)VKBPR00(Z/WZ__^+
ME"0\$```93,5%````(G8#X5Y`0``@<1,$```6UY?7<.)'"3HW.;__\=$)`2]
MR00(B30DB40D+.BHY___A<")QW2QBU0D+(UT)#R#P@&)5"0LC78`@#\`=06_
M2<D$"(7M=!2)?"0$B2PDZ);H__^%P`^$Q@```(D\).B&YO__@'P'_R]U%8VT
M)@````"#Z`&`?`?_+\8$!P!T\@-$)"P]_P\```^/2O___XE<)!C'1"04O\D$
M"(E\)!#'1"0,WLH$",=$)`@`$```QT0D!`$```")-"3HF^?__\<$)`````#H
M_^?__XL`B00DZ.7D__^)!"3H#>?__XET)`3'!"0#````B40D".CYX___A<!U
M+<<$)`````#HR>?__XL`B00DZ*_D__^)!"3HU^;__XM`$"4`\```/0"```!T
M(\=$)`2]R00(QP0D`````.B4YO__A<")QP^%^O[__^F4_O__QT0D!`$```")
M-"3HU>3__X7`=<F)\KBPR00(Z'WY__^)-"3HG>?__XG#Z7'^___H,>;__XGV
MC;PG`````(M$)`0/M@B$R70@C5`!ZPH/M@J#P@&$R701@/DO=?$/M@J)T(/"
M`83)=>_SPXUV`%.#[!B+7"0@A=MT+(`[`'0GB1PDZ!_E__^-1`/_.<-R#NM!
MD(UT)@"#Z`$YPW,U@#@O=/3K)V:0QP0D`@```.B4Y?__A<!T!6;'`"X`@\08
M6\.-M@````"`."]T!X/H`3G#<O0YV'48@#@O=%O'1"0@O\D$"(/$&%OIVN;_
M_V:0@^@!.<-S!8`X+W3TB<(QP"G:C4H"@?D`$```=["#P@''1"0,`!```(E4
M)`B)7"0$QP0D`$`%".@<XO__N`!`!0CKBI"-="8`QP0D`@```.@$Y?__B<(Q
MP(72#X1M____9L<"+@")T.EA____C70F`%=6@^PT9:$4````B40D+#'`H33+
M!`B)1"0*H3C+!`B)1"0.H3S+!`B)1"02H4#+!`B)1"06H43+!`B)1"0:H4C+
M!`B)1"0>H4S+!`B)1"0BH5#+!`B)1"0F#[<%5,L$"&:)1"0JN,')!`CH(?/_
M_[C*R00(Z!?S__^XTLD$".@-\___N-O)!`CH`_/__[CBR00(Z/GR__^X\LD$
M".CO\O__N*?)!`CHY?+__[C^R00(Z-OR__^X",H$".C1\O__N!+*!`CHQ_+_
M_[BPR00(Z+WR__^X',H$".BS\O__N"7*!`CHJ?+__[@PR@0(Z(_R__^%P'0,
MB<*X",H$".@_]___N$'*!`CH=?+__X7`=`R)PKA3R@0(Z"7W__^X7LH$".A;
M\O__A<!T+XG"N*?)!`CH"_?__[J*R@0(N.+)!`CH_/;__XM$)"QE,P44````
M=4F#Q#1>7\.0N&[*!`CH'O+__X7`=!*)PKC^R00(Z,[V___KP8UT)@"-="0;
MOW_*!`BY"@```/.F=:N-5"0EN/[)!`CHJ/;__^N;Z&GC__^0@^P,H:0_!0B#
M^/]T"X/$#,.-M"8`````N/[)!`CHOO'__XG",<"%TG0/#[82A-)T"#'`@/HP
M#Y7`HZ0_!0B#Q`S#C;0F`````(V\)P````"#[!SHD.+__XD$).AHXO__B<(Q
MP(72=`*+`H/$',-FD%575E.[ELH$"(/L7(M\)'"-="0XQT0D-);*!`C'1"0X
MC,H$",=$)#R9R@0(QT0D0(_*!`C'1"1$E,H$",=$)$BFR@0(QT0D3"C+!`CK
M'&:0B7PD!(D$).ALXO__A<!T.(L>@\8$@#L`="6)V.C_\/__A<")Q70%@#@`
M==2)V(GZZ*OU__^+'H/&!(`[`'7;@\1<6UY?7<.0B3PDZ)CA__^)+"2)1"0L
MZ(SA__^+5"0LC40"`HD$).@<XO__B6PD&,=$)!2]R00(B7PD$,=$)`S>R@0(
MQT0D"/_____'1"0$`0```(D$)(E$)"SHN.+__XM4)"R)V.@U]?__Z6#___]5
M5U93@>P\@0``BX0D4($``&6+%10```")E"0L@0``,=+'A"2`````O<H$",>$
M)(0```!)R00(B40D3+BGR00(QX0DB````"C+!`C'1"1<4\H$",=$)&!,R@0(
MQT0D9,+*!`C'1"1H:<H$",=$)&S*R@0(QT0D<"C+!`C'1"1TL<H$",=$)'C.
MR@0(QT0D?"C+!`CHV.___X7`=`F`.``/A?,"``#H-O[__X7`B<</A`P#```/
MMA^$VW0EZ/C?__^)^HVV`````(L(#[[;]@19"'4#Q@)?@\(!#[8:A-MUZ+T!
M````N%/*!`CK%(UT)@"+1*Q<@\4!@#@`#X1``@``Z&OO__^%P(G#=.7H4//_
M_X7`=-R)'"3H/.+__X7`=-")QHDT).@.X/__B3PDB</H!.#__XVL`P0$``")
M+"3HE>#__XDL)(G#B40D2.B'X/__B7PD',=$)!C7R@0(QT0D%+_)!`B)="00
MQT0D#-S*!`B)Q<=$)`C_____QT0D!`$```")!"3H'>'__\=$)`3M`0``B2PD
MZ!W=__^XC\H$".C+[O__A<`/A%,"``")!"3HH^'__XM\)$R)1"0$BP>)!"3H
M&?C__X7`B40D1`^$+0(``(M4)$2)%"3H6=___X/X`WXTBWPD1+D%````C70'
M_+_ER@0(\Z9U'H/X!`^$/0<``(M4)$2`?`+[+P^$+@<``(VV`````.AS_/__
MA<!U((M$)$3'1"0$`````(D$).BCX/__A<")1"1$#X7/`0``NHK*!`BX_LD$
M".C@\O__,?;H4=S__\=$)!PHRP0(QT0D%+_)!`B);"00QT0D#`/+!`C'1"0(
M_____XE$)!C'1"0$`0```(D<).@9X/__ZU6-M"8`````Z.O;__^#.!%U6>@!
MW/__@\8!QT0D("C+!`B)="0<QT0D%+_)!`B);"00QT0D#!'+!`B)1"08QT0D
M"/_____'1"0$`0```(D<).C"W___QT0D!.T!``")'"3HPMO__X/X_W2=B2PD
MZ$7=__^)VKBGR00(Z"'R__^)'"3HZ?O__XN4)"R!``!E,Q44````BT0D2`^%
M.`<``('$/($``%M>7UW#C;8`````BYPD@````+T!````@#L`=1;K/I"-="8`
MBYRL@````(/%`8`[`'0JB=CH\O#__X7`=.:)'"3HWM___X7`#X6>_?__BYRL
M@````(/%`8`[`'76,?;IBOW__XD$)(E$)$#H7/O__XM$)$")!"3HJ-___XE$
M)$CI7O___XVT)@````"[`0```+BQR@0(ZQ2-="8`BT2<=(/#`8`X``^$IP4`
M`.B+[/__A<!TYXD$).AGW___A<!TVXG'Z;C\__^-="8`BT0D3(L`B40D1.G$
M_?__D,=$)`P"````QT0D!.[____'1"0(_____XD$).A8V___BWPD1(V4)(P`
M``#'1"0(!@```(E4)`2)/"3HR=O__X"\)(P`````=0Z`O"2-````0P^$=04`
M`(M\)$3'1"0,`````,=$)`0`````QT0D"`````")/"3H_=K__XV$)*B```")
M;"1,B=W'A"2,@````2-%9\>$))"```")J\WOQX0DE(```/[<NIC'A"28@```
M=E0R$,>$))R```#PX=+#QX0DH(````````#'A"2D@````````,>$).B`````
M````B40D/(UT)@"+1"1$C;PDC````,=$)`@`@```B7PD!(D$).@!V___A<")
MQ@^.QP$``(N4)*"```")\XV\)(P```"-!/(YT`^2P@^VTHF$)*"```")\`&4
M)*2```#!Z!T!A"2D@```BX0DZ(```(7`=&>Z0````(GW*<(YUGX"B=>-E"2H
M@```C00"C90DC````(E\)`B)5"0$B00DZ(?;__^+A"3H@````?B#^$")A"3H
M@```#X5.____C80DC````(GS*?N-/#B-A"2,@```Z)S>__^-="8`@_L_#X[E
M````,?:0C70F`(L$-XF$)*B```"+1#<$B80DK(```(M$-PB)A"2P@```BT0W
M#(F$)+2```"+1#<0B80DN(```(M$-Q2)A"2\@```BT0W&(F$),"```"+1#<<
MB80DQ(```(M$-R")A"3(@```BT0W)(F$),R```"+1#<HB80DT(```(M$-RR)
MA"34@```BT0W,(F$)-B```"+1#<TB80DW(```(M$-SB)A"3@@```BT0W/(/&
M0(F$).2```"-A"2,@```Z,K=__^)V"GP@_@_#X\U____@^M`B=C!Z`:)PL'B
M!HU\.D`ITXV4)*B```#'1"0,1````(E<)`B)?"0$B10DZ"/9__^)G"3H@```
MZ1?^__^-M"8`````BU0D1(GKBVPD3(D4).BNVO__B[0DH(```(N4)*2```")
M\,'H`X/@/\:$!*B```"`@\`!@_@X#X]M`@``N3@```"-O"2H@```*<&-!`>)
M5"1`B4PD",=$)`0`````B00DZ'O8__^+5"1`B=#!Z!B(A"3@@```B=#!Z!"(
MA"3A@```B=#!Z`B(A"3B@```B?#!Z!B(A"3D@```B?#!Z!"(A"3E@```B?#!
MZ`B(A"3F@```B?`Q]HB$).>```"-A"2,@```B)0DXX```(V\).^```#HHMS_
M_XN4)(R```")T<'I&(G(B(PD&($``(G1P>D0B(PD&8$``(G1B)0D&X$``(N4
M))"```#!Z0B(C"0:@0``B='!Z1B(C"0<@0``B='!Z1"(C"0=@0``B=&(E"0?
M@0``BY0DE(```,'I"(B,)!Z!``")T<'I&(B,)""!``")T<'I$(B,)"&!``")
MT8B4)".!``"+E"28@```P>D(B(PD(H$``(G1P>D8B(PD)($``(G1P>D0B(PD
M)8$``(G1B)0D)X$``(N4))R```#!Z0B(C"0F@0``B='!Z1B(C"0H@0``B='!
MZ1"(C"0I@0``B='!Z0B(C"0J@0``B)0D*X$``.L,C70F``^VA#08@0``#[;`
MB40D$(T$=X/&`<=$)`S^R@0(QT0D"/_____'1"0$`0```(D$).BSV?__@_X4
M=<;&A"07@0```,=$)!PHRP0(B7PD&,=$)!2_R00(B6PD$,=$)`SOR@0(QT0D
M"/_____'1"0$`0```(D<).ANV?__Z;SY__^0BWPD3(M7!(72#X3)^/__B10D
MB50D0.C=U___BU0D0(/X`P^&L/C__XUT`OR_ZLH$"+D%````\Z8/A9KX__^)
M5"1$Z9'X__^_MLH$".E/]___C;PDJ(```+E`````*<&-!`>)3"0(B50D0,=$
M)`0`````B00DZ`[6__^-A"2,@```Z)K:__^+?"0\N0X````QP/.KBU0D0.EU
M_?__@+PDC@```$$/A7WZ__^`O"2/````0P^%;_K__X"\))````!(#X5A^O__
M@+PDD0```$4/A5/Z___'1"0,`@```,=$)`3&____QT0D"/____^)/"3H5-7_
M_XV$)(P```#'1"0(*0```(E$)`2)/"3HR=7__XV4)(P```#'1"0<*,L$"(E4
M)!CII_[__^B,U___C70F`%575E.#[!S'!"0`````Z)78__^+`(D$).A[U?__
MB00DZ//5___&``&XXLD$".C.Y?__A<!T"8`X,0^$`0,``)#H._+__\<$)```
M``#H5]C__XL`B00DZ#W5___'1"0,"P```,=$)`@!````QT0D!"++!`B)!"3H
MS=3__X7`#X3-````BT`,,?:+:!BAZ#\%"(/X`0^.K````+L!````ZR^+1PR+
M%>0_!0B+%)J)1"0$B10DZ!#8__^%P`^%@````*'H/P4(@\,!@\8!.=A^=L<$
M)`````#HS=?__XL`B00DZ+/4___'1"0,`````(ET)`B);"0$B00DZ!O6__^%
MP'0_BSCV1PD$=9?'!"0`````Z)/7__^+`(D$).AYU/__QT0D#`(```#'1"0(
M`````(E\)`2)!"3HW=?__^EC____H>@_!0B-4/\Y\@^$@`$``,<$)`````#H
M3-?__XL`B00DZ#+4___'1"0,!````,=$)`@!````QT0D!"?+!`B)!"3HPM/_
M_X7`B<-T/HM`#(LPQP0D`````.@+U___BP")!"3H\=/__\=$)`@IRP0(B70D
M!(D$).BMT___BT,,BQCV0PI`#X5.`0``QP0D`````.C2UO__BP")!"3HN-/_
M_\=$)`P$````QT0D"`$```#'1"0$+LH$"(D$).A(T___A<")PW0_N+#)!`CH
M\./__X7`B<8/A#X!``"+0PR+.,<$)`````#H?=;__XL`B00DZ&/3__^)="0(
MB7PD!(D$).@CT___QP0D`````.A7UO__BP")!"3H/=/__XD$).BUT___Q@``
MQP0D`````.@VUO__BP")!"3H'-/__XD$).A4UO__QP``````N*?)!`CH;./_
M_X7`H^P_!0@/A.<```#'1"0$[0$``(D$).B7T?__@_@1=!"%P'0,@_C_C78`
M#X4G`0``@\0<6UY?7<-FD(/X`0^.=_[__[L!````9I#'!"0`````@\,!Z+G5
M__^+`(D$).B?TO__B6PD!(D$).@STO__.1WH/P4(?]/I/O[__XVV`````,<$
M)`````#HA-7__XL`B00DZ&K2__^)7"0$B00DZ#[4___IB_[__Y"`>`$`#X3[
M_/__C;8`````Z>K\__^-=@"AY#\%"(LXBT,,BS#'!"0`````Z#C5__^+`(D$
M).@>TO__B?J)\.@MZ?__Z;W^__^AY#\%"(D$).C[\?__BSWD/P4(H^P_!0B+
M0PR+,/9&"00/A)8```"+1@R)?"0$B00DZ/K2__^)QHM##(L8]D,)!'1&BT,,
MB40D"*'D/P4(B70D#(L`QP0D6,L$"(E$)`3H"]3__XE$)`RA[#\%"(E$)`BA
MY#\%"(L`QP0DB,L$"(E$)`3HY]/__\<$)`````#HB]3__XL`B00DZ''1___'
M1"0,`@```,=$)`@`````B5PD!(D$).C5U/__ZXG'!"0`````Z%?4__^+`(D$
M).@]T?__QT0D#`(```#'1"0(`````(ET)`2)!"3HH=3__^DV____C70F`%93
M@^P4BW0D((DT).C_[/__#[80B<.$TG40ZQ^-="8`@\`!#[80A-)T$8#Z+W7Q
M@\`!#[80B<.$TG7OZ&#O__^%P'0=A?9T&8`^`'04QT0D!-?*!`B)'"3H>]+_
M_SG8=`:#Q!1;7L.#Q!2)\%M>Z9WC__^-M@````"-O"<`````@^P<QP0D````
M`.B9T___BP")!"3H?]#__\=$)`3_____B00DZ+_0___'!"0`````Z'/3__^+
M`(D$).A9T/__QT0D"`````#'1"0$(*<$"(D$).BQT___@\0<PY"-="8`58GE
M@^3P5E.#[#B-11")1"0(C44,B40D!(U%"(D$).@4T___QT0D"$B5!`C'1"0$
M2)4$",<$)"B7!`CHX`$``,<$)`````#H'-#__X`X`'4[Z`+0__^%P*/@/P4(
M#X2Q`0``B00DZ+W0___'!"0`````Z-'2__^+`(D$).BWS___B00DZ!_2___&
M``#'!"0`````,=OHKM+__XL`B00DZ)3/__^)!"3HK-+__X`(`L<$)`````#H
MC=+__XL`B00DZ'//__^)!"3HB]+__X`(`8M5"(E<)"R#P@6)5"0HWVPD*-@%
MV,L$"-T%X,L$"-G)VNG?X)X/AP4!``#!X@*)%"3HLM'__XMU#*/D/P4(BQ;'
M0`0NRP0(QT`(`,P$",=`##'+!`B)$(M=",<%Z#\%"`0```"#^P%^%;H!````
M9I"+#):)3)`,@\(!.=IU\H/#`\<$F`````")1"0,H>`_!0B)7"0(QT0D$```
M``#'1"0$P*X$"(D$).B;S?__A<")PW0]H>`_!0B)!"3H6-#__[CRR00(Z`;?
M__^%P'0ZH>`_!0B)!"3H3<W__^@HS___@\0XB=A;7HGL7<.0C70F`*'@/P4(
MB00DZ/O-__^)P^NRC;0F`````*'L/P4(A<!T"HD$).@W_?__Z[.XI\D$".BK
MWO__A<"C[#\%"'2@Z^''1"0$Q#\%",<$)*3)!`CHA-#__\<$)`$```#H>-'_
M_U6)Y5/H,@```('#`W8``(/L$(N#5`$``(E$)`R+11")1"0(BT4,B40D!(M%
M"(D$).A3S?__@\006UW#BQPDPY!5B>575E/H\/___X'#P74``(/L'.C_R___
MC;O@_O__C8/@_O__*<?!_P*%_W0D,?:+11")1"0(BT4,B40D!(M%"(D$)/^4
ML^#^__^#Q@$Y_G+>@\0<6UY?7<.-M@````!5B>5=PY"0D)"0D)"0D)"058GE
M4X/L!*$L/04(@_C_=!.[+#T%"&:0@^L$_]"+`X/X_W7T@\0$6UW#D)!5B>53
M@^P$Z`````!;@<,D=0``Z.S0__]96\G#```````````#`````0`"`"XN`"5S
M+R5S`"]P<F]C+W-E;&8O97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`
M4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%
M4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?
M,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$
M25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%.
M/0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52
M`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`'!A<BT`)7,E<R5S
M)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@`````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*`````````````````(#____/07!A<BYP;```
M`````````````````````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*
M"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A
M="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z
M.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@
M<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E
M8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@
M(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI
M;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O
M<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T
M9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@
M(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@
M56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM
M86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES
M('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD
M;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C
M('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@
M)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*
M("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*
M("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L
M)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M
M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%
M1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?
M96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[
M4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'
M5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I
M('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@
M("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@
M)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H
M"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E
M=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN
M9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'
M>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@
M9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G
M/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@
M(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB
M.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F
M:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@
M('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@
M("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@
M("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C
M<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@
M8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U
M9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@
M("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@
M=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%
M3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D
M;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@
M("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN
M86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]
M("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@
M("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@
M("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@
M(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@
M("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@
M("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E
M:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE
M*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@
M("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB
M=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T
M=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.
M0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@
M("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R
M97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@
M(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@
M=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T
M(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE
M<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E
M<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET
M96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA
M<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E
M<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N
M)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S
M('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY
M("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@
M("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R
M"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*
M("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA
M;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L
M"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E
M(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L
M9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N
M="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?
M:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*
M("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@
M<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B
M=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@
M)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/
M)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@
M("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L
M92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C
M:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF
M="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@
M("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@
M("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@
M("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@
M+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@
M;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@
M('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@
M("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@
M("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@
M("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*
M("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D
M97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@
M("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M
M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@
M("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L
M92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H
M*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I
M;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@
M("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E
M)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I
M;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@
M("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#
M;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES
M(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H
M92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H
M('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*
M("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I
M;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@
M=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@
M("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY
M("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B
M(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N
M+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*
M("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@
M("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@
M("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@
M("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@
M('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD
M(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@
M("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N
M,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H
M)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*
M("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70[
M"B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O
M9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*
M"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@
M4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q
M=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*
M("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@
M("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@
M("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@
M("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@
M("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@
M("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@
M("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@
M("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@
M("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@
M(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O
M("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*
M"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![
M>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@
M(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@
M("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97([
M"B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@
M(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U
M:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E
M($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E
M($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R
M97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@
M0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V
M97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER
M+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A
M<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@
M<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@
M("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@
M("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*
M("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V
M97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I
M9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M
M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@
M("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@
M("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R
M96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O
M7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@
M("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B
M(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY
M("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M
M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@
M("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@
M('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE
M;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F
M:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0
M<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*``````$;`SO0````&0````QS
M___L````7'[__RP!```<?___5`$``"Q___]L`0``?'___Y@!``"L@?__Q`$`
M``R#__\<`@``W(/__U@"``#,A?__G`(``-R&___(`@``'(?__^`"``",A___
M^`(``'R(__\@`P``C(C__S@#``!\BO__?`,``*R*__^0`P``G(O__\`#```\
MC?__\`,``(R-__\0!```K(W__R@$``"LCO__:`0``!R9__^L!```G)W___`$
M```<GO__+`4``'R>__]$!0``%``````````!>E(``7P(`1L,!`2(`0``/```
M`!P````8<O__00L```!!#@A!#@Q!#A!!#A1"@P6&!(<#A0)&#NP"`S`+#A1!
MPPX00<8.#$''#@A!Q0X$`"0```!<````*'W__[X`````0PY`1H,%5H4"AP.&
M!%,*#@3%Q\;#1@L4````A````,!]__\0`````$,.($P.!``H````G````+A]
M__]'`````$$."$*&`D$.#$4.($2#`W<.#$'##@A!Q@X$`"@```#(````W'W_
M_R("````00X(00X,0PX@1X,#A@(#$P(.#$'##@A!Q@X$5````/0```#@?___
M60$```!!#@A!#@Q"AP.%`D$.$$$.%$8.H`%$@P6&!$L*#A1!PPX00<8.#$''
M#@A!Q0X$00L"_@H.%$$.$,-!#@S&00X(QT$.!,5&"S@```!,`0``Z(#__\$`
M````00X(0H8"00X,0H,#0PX@>PH.#$'##@A!Q@X$0@L"=`X,0PX(PT$.!,8`
M`$````"(`0``?('__^X!````00X(00X,00X00H8$AP.%`D$.%$4.4$*#!0)/
M"@X40<,.$$'&#@Q!QPX(0<4.!$@+````*````,P!```H@___#0$```!&#L`@
M2X<#28,%284":88$`HH*#@3%Q\;#0@L4````^`$```R$__\]`````$,.('D.
M!``4````$`(``#2$__]K`````$,.,`)G#@0D````*`(``(R$___B`````$8.
MP$!.@P1)A@-6AP("8@H.!,?&PT,+%````%`"``!4A?__"P````!##A!##@0`
M0````&@"``!,A?__YP$```!!#@A!#@Q!#A!!#A1&#N`@6X,%A@2'`X4"`DH*
M#A1!PPX00<8.#$''#@A!Q0X$00L````0````K`(``/B&__\M`````````"P`
M``#``@``%(?__^P`````00X(0PX@1(,"`D@*#@A!PPX$1PM@"@X(0<,.!$<+
M`"P```#P`@``U(?__Y\!````00X(00X,0PY``F6&`X<"`NH*#@Q!Q@X(0<<.
M!$(+`!P````@`P``1(G__T(`````0PX030H.!$@+:0X$````%````$`#``!T
MB?__'@````!##B!:#@0`/````%@#``!\B?__``$```!!#@A!#@Q!#A!!#A1%
M@P6&!(<#A0)##G`"A@H.%$'##A!!Q@X,0<<."$'%#@1""T````"8`P``/(K_
M_VP*````00X(00X,00X000X41@[0@@("B8,%A@2'`X4"`Z(""@X40<,.$$'&
M#@Q!QPX(0<4.!$<+0````-P#``!HE/__?`0```!!#@A!#@Q!#A!!#A1##C!'
M@P6&!(<#A0(#NP(*#A1!PPX00<8.#$''#@A!Q0X$0PL````X````(`0``*28
M__]S`````$$."$$.#$,.($2#`X8"`EL*#@Q!PPX(0<8.!$$+0PX,0\,."$'&
M#@0````4````7`0``.B8__];`````$,.(`)7#@0\````=`0``#"9__\@`@``
M`$$."$*%`@T%7!`#"'4`"?`:"?@B$`8(=0`)\!H)_"(#EP$*PT'&0@T$0<4.
M!$8+`````/____\`````_____P```````````0````$````!````K0(```$`
M``"Y`@```0```,0"```!````S@(```$```#<`@```0```.D"```!````.`,`
M``\```"E!```#````)B4!`@-````',D$"/7^_V]H@00(!0```!"*!`@&````
MP(($"`H```!<!@``"P```!`````5``````````,```!,/@4(`@```(@"```4
M````$0```!<````0D@0($0```/B1!`@2````&````!,````(````_O__;UB1
M!`C___]O`@```/#__V]LD`0(````````````````````````````````````
M`````````````````````````````````$`]!0@``````````-Z4!`CNE`0(
M_I0$"`Z5!`@>E00(+I4$"#Z5!`A.E00(7I4$"&Z5!`A^E00(CI4$")Z5!`BN
ME00(OI4$",Z5!`C>E00([I4$"/Z5!`@.E@0('I8$""Z6!`@^E@0(3I8$"%Z6
M!`ANE@0(?I8$"(Z6!`B>E@0(KI8$"+Z6!`C.E@0(WI8$".Z6!`C^E@0(#I<$
M"!Z7!`@NEP0(/I<$"$Z7!`A>EP0(;I<$"'Z7!`B.EP0(GI<$"*Z7!`B^EP0(
MSI<$"-Z7!`CNEP0(_I<$"`Z8!`@>F`0(+I@$"#Z8!`A.F`0(7I@$"&Z8!`A^
MF`0(CI@$")Z8!`BNF`0(OI@$",Z8!`C>F`0([I@$"/Z8!`@.F00('ID$""Z9
M!`@^F00(3ID$"%Z9!`ANF00(?ID$"(Z9!`B>F00(KID$"+Z9!`C.F00(WID$
M"```````````_____^C+!`B@6P``1T-#.B`H1TY5*2`T+C4N,@``+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T
M`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````"P````$````"````-($$"#0!
M```3```````````````!`````````!,````'`````@```$B!!`A(`0``(```
M````````````!``````````A````]O__;P(```!H@00(:`$``%@!```$````
M``````0````$````*P````L````"````P(($",`"``!0!P``!0````$````$
M````$````#,````#`````@```!"*!`@0"@``7`8``````````````0``````
M```[````____;P(```!LD`0(;!```.H````$``````````(````"````2```
M`/[__V\"````6)$$"%@1``"@````!0````(````$`````````%<````)````
M`@```/B1!`CX$0``&`````0`````````!`````@```!@````"0````(````0
MD@0($!(``(@"```$````"P````0````(````:0````$````&````F)0$")@4
M```P```````````````$`````````&0````!````!@```,B4!`C(%```(`4`
M````````````!`````0```!O`````0````8```#PF00(\!D``"PO````````
M`````!``````````=0````$````&````',D$"!Q)```<```````````````$
M`````````'L````!`````@```$#)!`A`20``85X`````````````(```````
M``"#`````0````(```"D)P4(I*<``-0```````````````0`````````D0``
M``$````"````>"@%"'BH``"T!``````````````$`````````)L````!````
M`P```"P]!0@LK0``"```````````````!`````````"B`````0````,````T
M/04(-*T```@```````````````0`````````J0````$````#````/#T%"#RM
M```$```````````````$`````````*X````&`````P```$`]!0A`K0``"`$`
M``4`````````!`````@```"W`````0````,```!(/@4(2*X```0`````````
M``````0````$````O`````$````#````3#X%"$RN``!0`0`````````````$
M````!````,4````!`````P```)P_!0B<KP``%```````````````!```````
M``#+````"`````,```#`/P4(L*\``$`0`````````````"``````````T```
M``$````P`````````+"O```1```````````````!`````0````$````#````
@``````````#!KP``V0```````````````0``````````
